@@ -13,7 +13,6 @@ package ${package};
 
 use strict;
 use warnings;
-# @@protoc_insertion_point(after_pragmas)
 use MIME::Base64 qw();
 use Google::ProtocolBuffers::Dynamic;
 
@@ -21,13 +20,9 @@ my $gpd = Google::ProtocolBuffers::Dynamic->new;
 
 ${load_blobs}
 
-# @@protoc_insertion_point(after_loading)
-
 $gpd->map(
 ${mappings});
 
-# @@protoc_insertion_point(after_mapping)
-
 undef $gpd;
 
 1;
@@ -44,8 +39,7 @@ sub generate_to {
 sub generate {
     my ($class, %args) = @_;
     my $mappings = do {
-        package # hide from PAUSE indexer
-            Data::Dumper;
+        package Data::Dumper;
 
         our ($Terse, $Indent, $Purity, $Deepcopy, $Pad, $Sortkeys);
         local $Terse = 1;
@@ -55,12 +49,7 @@ sub generate {
         local $Pad = '    ';
         local $Sortkeys = 1;
         join "", map {
-            my $dump = Dumper($_);
-            $dump =~ s{$}{,};
-            # the '+' is to make sure Perl::Critic does not consider
-            # this an anonymous subroutine
-            $dump =~ s[^(\s+)\s(\{)][$1+$2]mg;
-            $dump
+            (my $dump = Dumper($_)) =~ s{$}{,}; $dump
         } @{$args{mappings}};
     };
     my @descriptors = @{$args{descriptors} || []};
@@ -100,32 +89,17 @@ sub _to_perl_package {
 }
 
 my %boolean_options = map +($_ => [$_, 1], "no_$_" => [$_, 0]), qw(
-    decode_blessed
-    implicit_maps
     use_bigints
     check_required_fields
     explicit_defaults
     encode_defaults
-    encode_defaults_proto3
     check_enum_values
-    fail_ref_coercion
-    ignore_undef_fields
     generic_extension_methods
 );
 
-my %string_options = map { $_ => 1 } qw(
-    accessor_style
-    client_services
-    boolean_values
-);
-
 sub _to_option {
     my ($options, $key, $value) = @_;
 
-    if (exists $string_options{$key}) {
-        $options->{$key} = $value;
-        return 1;
-    }
     return 0 unless my $boolean = $boolean_options{$key};
     $options->{$boolean->[0]} = $boolean->[1];
 
@@ -150,7 +124,6 @@ sub generate_codegen_request {
     for my $file (@{$request->get_proto_file_list}) {
         next unless $files{$file->get_name};
         $pb_packages{$file->get_package} = 1;
-        $file->clear_source_code_info;
         $descriptors->add_file($file);
     }
 
@@ -164,15 +137,9 @@ sub generate_codegen_request {
         } elsif ($key eq 'map_package') {
             push @mappings, $mapping = {};
             $mapping->{package} = $value;
-        } elsif ($key eq 'map_message') {
-            push @mappings, $mapping = {};
-            $mapping->{message} = $value;
-        } elsif ($key eq 'pb_prefix') {
-            push @mappings, $mapping = {};
-            $mapping->{pb_prefix} = $value;
-        } elsif ($key eq 'prefix' || $key eq 'to') {
-            $mapping->{$key} = _perlify_package($value);
-        } elsif (!_to_option(($mapping ? $mapping->{options} //= {} : \%global_options), $key, $value)) {
+        } elsif ($key eq 'prefix') {
+            $mapping->{prefix} = _perlify_package($value);
+        } elsif (!_to_option(($mapping ? $mapping->{options} : \%global_options), $key, $value)) {
             return error("Unrecognized option key '$key'");
         }
     }
@@ -206,7 +173,6 @@ sub generate_codegen_request {
             content => $code,
         }),
     );
-    $response->set_supported_features(Google::ProtocolBuffers::Dynamic::ProtocInterface::CodeGeneratorResponse::Feature::FEATURE_PROTO3_OPTIONAL);
 
     return $response;
 }
@@ -225,7 +191,7 @@ Google::ProtocolBuffers::Dynamic::MakeModule
 
 =head1 VERSION
 
-version 0.42_07
+version 0.01
 
 =head1 AUTHOR
 
@@ -233,7 +199,7 @@ Mattia Barbon <mattia@barbon.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015-2016 by Mattia Barbon.
+This software is copyright (c) 2015 by Mattia Barbon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
