@@ -6,31 +6,6 @@ use Google::ProtocolBuffers::Dynamic::ProtocInterface;
 
 sub import {
     my ($class, %args) = @_;
-
-    if (@ARGV && grep /^(?:--help|-h)$/, @ARGV) {
-        my $message = 'This is a protoc plugin and should not be used directly. Use --man for documentation';
-
-        if ('podusage' eq ($args{help} // '')) {
-            require Pod::Usage;
-
-            Pod::Usage::pod2usage(
-                -message => $message . "\n",
-                -exitval => 1,
-            );
-        } else {
-            print STDERR $message, "\n\n";
-
-            exit 1;
-        }
-    } elsif (@ARGV && grep /^--man$/, @ARGV) {
-        require Pod::Usage;
-
-        Pod::Usage::pod2usage(
-            -exitval => 0,
-            -verbose => 2,
-        );
-    }
-
     my $generator = $args{run};
     eval "require $generator; 1"
         or die "Error loding plugin '$generator': $@";
@@ -76,7 +51,7 @@ Google::ProtocolBuffers::Dynamic::ProtocPlugin
 
 =head1 VERSION
 
-version 0.42_07
+version 0.01
 
 =head1 AUTHOR
 
@@ -84,7 +59,7 @@ Mattia Barbon <mattia@barbon.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015-2016 by Mattia Barbon.
+This software is copyright (c) 2015 by Mattia Barbon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
